AppButton class

Inheritance

Constructors

AppButton({Key? key, required ButtonType type, VoidCallback? onPressed, ButtonVariant variant = ButtonVariant.elevated, String? customLabel, bool isLoading = false, bool fullWidth = true, Color? customColor, Color? customTextColor, double? customBorderRadius, double? customElevation, EdgeInsetsGeometry? customPadding, TextStyle? customTextStyle, double? customIconSize, BorderSide? customBorderSide, Size? customMinSize, Widget? customChild, GestureConfig? gestureConfig})
const

Properties

customBorderRadius double?
final
customBorderSide BorderSide?
final
customChild Widget?
final
customColor Color?
final
customElevation double?
final
customIconSize double?
final
customLabel String?
final
customMinSize Size?
final
customPadding EdgeInsetsGeometry?
final
customTextColor Color?
final
customTextStyle TextStyle?
final
fullWidth bool
final
gestureConfig GestureConfig?
final
hashCode int
The hash code for this object.
no setterinherited
isLoading bool
final
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
onPressed VoidCallback?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ButtonType
final
variant ButtonVariant
final

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited